@@ -3,7 +3,7 @@ CONF_DEVICENAME = "dn"
 CONF_FRIENDLYNAME = "fn"
 CONF_FULLTOPIC = "t_f"
 CONF_HOSTNAME = "hn"
-CONF_ID = "id"
+CONF_MAC = "mac"
 CONF_LIGHT = "li"
 CONF_MODEL = "md"
 CONF_OFFLINE = "ofl"
